## textWindow.py - the code for firstboot TUI
##
## Copyright (C) 2002, 2003 Red Hat, Inc.
## Copyright (C) 2002, 2003 Brent Fox <bfox@redhat.com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

from snack import *
import popen2
import os
import sys
import string
from constants_text import *

##
## I18N
## 
from rhpl.translate import _, N_
import rhpl.translate as translate
translate.textdomain ("firstboot")


class TextWindow:
    def runOVSmakerepo(self):
        # Get the hostname of the machine
        (output, input) = popen2.popen4('/bin/uname -n')
        lines = output.readlines()
        hostname = None
        if len(lines) >= 1:
            hostname = lines[0].strip()
        output.close()
        input.close()

        # Get the device formatted with OCFS2
        (output, input) = popen2.popen4('/bin/grep ocfs2 /proc/mounts | /bin/cut -f1 -d\' \' | /usr/bin/head -1')
        lines = output.readlines()
        device = None
        if len(lines) >= 1:
            device = lines[0].strip()
        output.close()
        input.close()

        if not hostname and not device:
            return None

        # Temporarily turn down the printk level to avoid printing garbage
        os.system('/sbin/sysctl kernel.printk=0 > /dev/null 2&>1')

	# umount the local mountpoint and comment it out of /etc/fstab
        os.system('/bin/umount /OVS/local > /dev/null 2&>1')
        os.system('/bin/sed -i \'s|^%s|# %s|\' /etc/fstab > /dev/null 2&>1' %(device, device))

        # Run the makerepo command
        message = '\"local ocfs2 storage on %s\"' %(hostname)
        os.system('/usr/lib/ovs/ovs-makerepo %s 0 %s > /dev/null' %(device, message))

        # Restore the printk level 
        os.system('/sbin/sysctl kernel.printk=6 > /dev/null 2&>1')

    def _exitForSure(self, screen):
        '''
        Dialog box that verifies the user really disagrees with EULA.
        Returns -1 if the user chooses \'Yes\' (wants to reconsider the EULA) and -2 if the user chooses \'No\' (Disagrees) 
        '''

        textbox = Textbox(60, 3, _("Do you want to reread or reconsider the Licence Agreement?\nIf not, please shut down the computer and remove this product from your system. "), wrap = 1)
        bb = ButtonBar(screen, [_("Yes"), _("No")])
        gridForm = GridFormHelp(screen, _("Are you sure?"), "", 1, 4)
	gridForm.add(textbox, 0, 1)
	gridForm.add(bb, 0, 2, growx = 1)

        button = bb.buttonPressed(gridForm.runOnce())
	if button == "yes":
            return -1
        else:
            return -2
        
    def eula(self, screen):
	'''
        Displays the EULA and prompts the user to agree or disgree to the license.
        Returns 0 if the user agrees to the agreement, and the return value of _exitForSure otherwise.
        '''

        lang = os.environ["LANG"]
        if len(string.split(lang, ".")) > 1:
            lang = string.split(lang, ".")[0]

        path = "/usr/share/eula/eula.%s" % lang
        if not os.access(path, os.R_OK):
            #If we don't have a translation for this locale, just open the English one
            lines = open("/usr/share/eula/eula.en_US").readlines()
        else:
            #Try to open the translated eula
            lines = open(path).readlines()

        license = reflow("".join(lines), 60)

        textbox = TextboxReflowed(50, _("Please read and agree to the End User License Agreement"))
        licenseText = Textbox(60, 10, license[0], scroll = 1)
        bb = ButtonBar(screen, [_("Agree"), _("Disagree")])
        gridForm = GridFormHelp(screen, _("End User License Agreement"), "", 1, 4)
	gridForm.add(textbox, 0, 1)
	gridForm.add(licenseText, 0, 2)
	gridForm.add(bb, 0, 3, growx = 1)

        button = bb.buttonPressed(gridForm.runOnce())
	
	if button == "agree":
            return 0
        else:
            return self._exitForSure(screen)

    def moduleList(self, screen):
        '''
        Standard firstboot dialog when the system has no X
        '''

        toolList = [(_("Authentication"), ("/usr/sbin/authconfig-tui"), ("")),
                    (_("Firewall configuration"), ("/usr/bin/system-config-securitylevel-tui"), ("selinux disabled")),
                    (_("Keyboard configuration"), ("/usr/bin/system-config-keyboard"), ("--text")),
                    (_("Network configuration"), ("/usr/sbin/system-config-network-tui"), ("")),
                    (_("Printer configuration"), ("/usr/sbin/printconf-tui"), ("")),
                    (_("System services"), ("/usr/sbin/ntsysv"), ("")),
                    (_("Timezone configuration"), ("/usr/sbin/timeconfig"), ("")),
                    (_("ULN Register"), ("/usr/bin/rhn_register"), (""))]

        bb = ButtonBar(screen, [_("Run Tool"), TEXT_EXIT_BUTTON])

        textbox = TextboxReflowed(50, _("Select the item that you wish to modify "))
        self.listbox = Listbox(8, scroll=1, returnExit=0)

        for name, tool, args in toolList:
            # Make sure we can access the program before adding it.
            if os.access(tool, os.X_OK):
                self.listbox.append(name, string.join([tool, args]))

        gridForm = GridFormHelp(screen, _("Setup Agent"), "", 1, 4)
        gridForm.add(textbox, 0, 0)
        gridForm.add(self.listbox, 0, 1, padding = (0, 1, 0, 1))
        gridForm.add(bb, 0, 3, growx = 1)

        button = bb.buttonPressed(gridForm.runOnce())

        if button == TEXT_EXIT_CHECK:
            return -1
        else:
            #They've selected to run a config tool.  Lauch it now
            choice = self.listbox.current()
            os.system(choice)
            return 0
